@@ -3,10 +3,6 @@ from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObj
 
 
 class Hall(QuickRestoObject):
-    @property
-    def version(self) -> int:
-        return self._version
-
     @property
     def deleted(self) -> bool:
         return self._deleted
@@ -27,13 +23,12 @@ class Hall(QuickRestoObject):
     def title(self) -> str:
         return self._title
 
-    def __init__(self, version: int = None, deleted: bool = None, tables: list = None, width: int = None,
+    def __init__(self, deleted: bool = None, tables: list = None, width: int = None,
                  height: int = None, title: str = None, **kwargs):
-        class_name = "ru.edgex.quickresto.modules.front.tablemanagement.Hall"
+        class_name = "ru.edgex.quickresto.modules.front.tablemanagement.hall.Hall"
         
         super().__init__(class_name=class_name, **kwargs)
 
-        self._version: int = version
         self._deleted: bool = deleted
         
         if tables is not None: 
