@@ -85,14 +85,22 @@ class Modifier(QuickRestoObject):
     def store_item_tag(self) -> StoreItemTag:
         return self._store_item_tag
 
+    @property
+    def parent_id(self) -> int:
+        return self._parent_id
+
+    @property
+    def parent_item(self) -> dict:
+        return self._parent_item
+
     def __init__(self, name: str = None, measureUnit: dict = None, color: str = None, displayOnTerminal: bool = None,
                  minValue: int = None, maxValue: int = None, withDish: bool = None,
                  modifierSales: list = None, excludeDiscount: bool = None, excludeMarkup: bool = None,
-                 article: int = None, itemTitle: str = None,
+                 article: int = None, itemTitle: str = None, parentId:int = None, parentItem:dict = None,
                  titleInPrice: str = None, storeQuantityKg: float = None, defaultValue: int = None,
                  basePriceInList: float = None, pack: float = None, recipe: str = None,
                  price: float = None, minimalPrice: float = None, deleted: bool = None, storeItemTag=None, **kwargs):
-        class_name = "ru.edgex.quickresto.modules.warehouse.nomenclature.mods.ModifierGroup"
+        class_name = "ru.edgex.quickresto.modules.warehouse.nomenclature.mods.Modifier"
 
         super().__init__(class_name=class_name, **kwargs)
 
@@ -127,3 +135,7 @@ class Modifier(QuickRestoObject):
             self._store_item_tag = StoreItemTag(**storeItemTag)
         else:
             self._store_item_tag = None
+
+        self._parent_id = parentId
+        self._parent_item = parentItem
+        
\ No newline at end of file
